@@ -1,11 +1,13 @@
 package LEOCHARRE::Dir;
+use Carp;
 use strict;
 use vars qw($VERSION @ISA %EXPORT_TAGS @EXPORT_OK);
 use Exporter;
 @ISA = qw/Exporter/;
 @EXPORT_OK = qw(reqdir ls lsa lsf lsfa lsd lsda lsr lsfr lsdr);
 %EXPORT_TAGS = ( all => \@EXPORT_OK );
-$VERSION = sprintf "%d.%02d", q$Revision: 1.3 $ =~ /(\d+)/g;
+$VERSION = sprintf "%d.%02d", q$Revision: 1.5 $ =~ /(\d+)/g;
+
 
 *reqdir = \&__require_dir;
 *ls     = \&__ls;
@@ -20,22 +22,22 @@ $VERSION = sprintf "%d.%02d", q$Revision: 1.3 $ =~ /(\d+)/g;
 
 sub __require_dir {
    require Cwd;
-   my $_d = Cwd::abs_path(+shift) or die;
+   my $_d = Cwd::abs_path($_[0]) or croak("Bad or missing argument '@_'.");
    -d $_d or mkdir $_d or warn("cant mkdir $_d") and return;
    return $_d;
 }
 
 sub __ls {
-   $_[0] or die('missing argument');
-   opendir(DIR, $_[0]) or die("cant open dir '$_[0]', $!");
+   $_[0] or croak("Bad or missing argument.");
+   opendir(DIR, $_[0]) or die("Cant open dir '$_[0]', $!");
    my @ls = grep { !/^\.+$/ } readdir DIR;
    closedir DIR;
    return @ls;
 }
 sub __lsa {
-   $_[0] or die('missing argument');
+   $_[0] or croak("Bad or missing argument");
    require Cwd;
-   my $abs = Cwd::abs_path($_[0]) or die;
+   my $abs = Cwd::abs_path($_[0]) or die("Can't resolve abs path to '@_'");
    my @ls = map { "$abs/$_" } __ls($abs);
    return @ls;
 }
@@ -43,7 +45,8 @@ sub __lsa {
 
 # no leading path
 sub __lsf  { return ( grep { -f "$_[0]/$_" }       __ls(   $_[0]) ) }
-sub __lsd  { return ( grep { -d "$_[0]/$_" }       __ls(   $_[0]) ) }
+#sub __lsd  { return ( grep { -d "$_[0]/$_" }       __ls(   $_[0]) ) }
+*__lsd = \&__lsreaddir;
 
 # absolute path
 sub __lsfa { return ( grep   -f,                   __lsa(  $_[0]) ) } 
@@ -65,6 +68,14 @@ sub __rel2docroot {
 }
 
 
+sub __lsreaddir{
+   $_[0] or croak('missing dir arg');
+   opendir(DIR, $_[0]) or croak("Can't open $_[0], $!");
+   my @lsd = grep { !/^\.+$/ } readdir(DIR);
+   closedir DIR;
+   return @lsd;
+}
+   
 
 1;
 
